@@ -133,6 +133,7 @@ namespace acommon {
     bool extOnly = false;
     
     if (    ( toMagic == "" )
+         || ( toMagic == "<noregex>" )
          || ( toMagic == "<nomagic>" )
          || ( toMagic == "<empty>" ) ) {
       extOnly = true;
@@ -325,9 +326,9 @@ namespace acommon {
 
     number.erase(magicFilePosition,magic.size() - magicFilePosition);
 
-    char * num = (char *)number.str();
-    char * numEnd = num + number.size();
-    char * endHere = numEnd;
+    const char * num = number.str();
+    const char * numEnd = num + number.size();
+    const char * endHere = numEnd;
     long position = 0;
 
     if (    ( number.size() == 0 ) 
@@ -561,8 +562,7 @@ namespace acommon {
         pathPos = pathPosEnd + 1;
       }
       possMode.erase(0,pathPos);
-      possMode.ensure_null_end();
-      to_lower(possMode.data());
+      to_lower(possMode.mstr());
 
       Vector<FilterMode>::iterator fmIt = filter_modes->begin();
 
@@ -696,15 +696,14 @@ namespace acommon {
 
             // partially unescape magic
             
-            magic.ensure_null_end();
-            char * dest = magic.data();
-            const char * src  = magic.data();
+            char * dest = magic.mstr();
+            const char * src  = magic.mstr();
             while (*src) {
               if (*src == '\\' && src[1] == '/' || src[1] == '#')
                 ++src;
               *dest++ = *src++;
             }
-            magic.resize(dest - magic.data());
+            magic.resize(dest - magic.mstr());
 
             PosibErr<bool> pe;
 
