@@ -21,6 +21,30 @@ using namespace std;
 using namespace aspeller;
 using namespace acommon;
 
+typedef const char * Str;
+typedef unsigned char byte;
+
+struct Hash {
+  InsensitiveHash f;
+  Hash(const Language * l) : f(l) {}
+  size_t operator() (Str s) const {
+    return f(s);
+  }
+};
+
+struct Equal {
+  InsensitiveEqual f;
+  Equal(const Language * l) : f(l) {}
+  bool operator() (Str a, Str b) const {
+    return f(a, b);
+  }
+};
+
+typedef Vector<Str> StrVector;
+
+typedef hash_set<Str,Hash,Equal> WordLookup;
+typedef hash_map<Str,StrVector>  SoundslikeLookup;
+
 class WritableBase : public Dictionary {
 protected:
   String suffix;
@@ -32,28 +56,39 @@ protected:
     
   WritableBase(BasicType t, const char * n, const char * s, const char * cs)
     : Dictionary(t,n),
-      suffix(s), compatibility_suffix(cs) {}
+      suffix(s), compatibility_suffix(cs),
+      use_soundslike(true) {fast_lookup = true;}
   virtual ~WritableBase() {}
-    
+  
   virtual PosibErr<void> save(FStream &, ParmString) = 0;
-  virtual PosibErr<void> merge(FStream &, ParmString, const Config * = 0) = 0;
+  virtual PosibErr<void> merge(FStream &, ParmString, Config * = 0) = 0;
     
   PosibErr<void> save2(FStream &, ParmString);
   PosibErr<void> update(FStream &, ParmString);
   PosibErr<void> save(bool do_update);
   PosibErr<void> update_file_date_info(FStream &);
-  PosibErr<void> load(ParmString, const Config &, LocalDictList *,
-                      SpellerImpl *, const LocalDictInfo *);
+  PosibErr<void> load(ParmString, Config &, DictList *, SpellerImpl *);
   PosibErr<void> merge(ParmString);
   PosibErr<void> save_as(ParmString);
 
   String file_encoding;
   ConvObj iconv;
   ConvObj oconv;
-  PosibErr<void> set_file_encoding(ParmString, const Config * c);
+  PosibErr<void> set_file_encoding(ParmString, Config & c);
 
   PosibErr<void> synchronize() {return save(true);}
   PosibErr<void> save_noupdate() {return save(false);}
+
+  bool use_soundslike;
+  StackPtr<WordLookup> word_lookup;
+  SoundslikeLookup     soundslike_lookup_;
+  ObjStack             buffer;
+ 
+  void set_lang_hook(Config & c) {
+    set_file_encoding(lang()->data_encoding(), c);
+    word_lookup.reset(new WordLookup(10, Hash(lang()), Equal(lang())));
+    use_soundslike = lang()->have_soundslike();
+  }
 };
 
 PosibErr<void> WritableBase::update_file_date_info(FStream & f) {
@@ -62,9 +97,8 @@ PosibErr<void> WritableBase::update_file_date_info(FStream & f) {
   return no_err;
 }
   
-PosibErr<void> WritableBase::load(ParmString f0, const Config & config,
-                                  LocalDictList *,
-                                  SpellerImpl *, const LocalDictInfo *)
+PosibErr<void> WritableBase::load(ParmString f0, Config & config,
+                                  DictList *, SpellerImpl *)
 {
   set_file_name(f0);
   const String f = file_name();
@@ -161,12 +195,12 @@ PosibErr<void> WritableBase::save(bool do_update) {
   return no_err;
 }
 
-PosibErr<void> WritableBase::set_file_encoding(ParmString enc, const Config * c)
+PosibErr<void> WritableBase::set_file_encoding(ParmString enc, Config & c)
 {
   if (enc == file_encoding) return no_err;
-  if (enc == "") enc = lang()->charset();
-  RET_ON_ERR(iconv.setup(*c, enc, lang()->charset()));
-  RET_ON_ERR(oconv.setup(*c, lang()->charset(), enc));
+  if (enc == "") enc = lang()->charmap();
+  RET_ON_ERR(iconv.setup(c, enc, lang()->charmap(), NormFrom));
+  RET_ON_ERR(oconv.setup(c, lang()->charmap(), enc, NormTo));
   if (iconv || oconv) 
     file_encoding = enc;
   else
@@ -180,52 +214,49 @@ PosibErr<void> WritableBase::set_file_encoding(ParmString enc, const Config * c)
 //  Common Stuff
 //
 
-typedef const char * Str;
+// a word is stored in memory as follows
+//   <word info><size><word...><null>
+// the hash table points to the word and not the start of the block
 
-struct Hash {
-  InsensitiveHash f;
-  Hash(const Language * l) : f(l) {}
-  size_t operator() (Str s) const {
-    return f(s);
-  }
-};
+static inline void set_word(WordEntry & res, Str w)
+{
+  res.word      = w;
+  res.word_size = (byte)w[-1];
+  res.word_info = (byte)w[-2];
+  res.aff       = "";
+}
 
-struct Equal {
-  InsensitiveEqual f;
-  Equal(const Language * l) : f(l) {}
-  bool operator() (Str a, Str b) const
-  {
-    return f(a, b);
-  }
-};
+// a soundslike is stored in memory as follows
+//   <word info><size><sl...><null>
+// the hash table points to the sl and not the start of the block
 
-typedef Vector<Str> StrVector;
-
-typedef hash_set<Str,Hash,Equal> WordLookup;
-typedef hash_map<Str,StrVector>  SoundslikeLookup;
+static inline void set_sl(WordEntry & res, Str w)
+{
+  res.word      = w;
+  res.word_size = (byte)w[-1];
+}
 
 static void soundslike_next(WordEntry * w)
 {
-  const char * const * i   = (const char * const *)(w->intr[0]);
-  const char * const * end = (const char * const *)(w->intr[1]);
-  w->word = *i;
+  const Str * i   = (const Str *)(w->intr[0]);
+  const Str * end = (const Str *)(w->intr[1]);
+  set_word(*w, *i);
   ++i;
   if (i == end) w->adv_ = 0;
 }
 
 static void sl_init(const StrVector * tmp, WordEntry & o)
 {
-  const char * const * i   = tmp->pbegin();
-  const char * const * end = tmp->pend();
-  o.word = *i;
-  o.aff  = "";
+  const Str * i   = tmp->pbegin();
+  const Str * end = tmp->pend();
+  set_word(o, *i);
   ++i;
   if (i != end) {
     o.intr[0] = (void *)i;
     o.intr[1] = (void *)end;
     o.adv_ = soundslike_next;
   } else {
-     o.intr[0] = 0;
+    o.intr[0] = 0;
   }
 }
 
@@ -244,14 +275,14 @@ struct SoundslikeElements : public SoundslikeEnumeration {
 
   WordEntry * next(int) {
     if (i == end) return 0;
-    d.word = i->first;
+    set_sl(d, i->first);
     d.intr[0] = (void *)(&i->second);
     ++i;
     return &d;
   }
 };
 
-struct StrippedElements : public SoundslikeEnumeration {
+struct CleanElements : public SoundslikeEnumeration {
 
   typedef WordLookup::const_iterator Itr;
 
@@ -260,14 +291,13 @@ struct StrippedElements : public SoundslikeEnumeration {
 
   WordEntry d;
 
-  StrippedElements(Itr i0, Itr end0) : i(i0), end(end0) {
+  CleanElements(Itr i0, Itr end0) : i(i0), end(end0) {
     d.what = WordEntry::Word;
-    d.aff  = "";
   }
 
   WordEntry * next(int) {
     if (i == end) return 0;
-    d.word = *i;
+    set_word(d, *i);
     ++i;
     return &d;
   }
@@ -280,7 +310,7 @@ struct ElementsParms {
   WordEntry data;
   ElementsParms(Iterator e) : end_(e) {}
   bool endf(Iterator i) const {return i==end_;}
-  Value deref(Iterator i) {data.word = *i; return &data;}
+  Value deref(Iterator i) {set_word(data, *i); return &data;}
   static Value end_state() {return 0;}
 };
 
@@ -292,34 +322,22 @@ struct ElementsParms {
 class WritableDict : public WritableBase
 {
 public: //but don't use
-  StackPtr<WordLookup> word_lookup;
-  SoundslikeLookup     soundslike_lookup_;
-  ObjStack             buffer;
-
   PosibErr<void> save(FStream &, ParmString);
-  PosibErr<void> merge(FStream &, ParmString, const Config * config);
+  PosibErr<void> merge(FStream &, ParmString, Config * config);
 
-protected:
-  void set_lang_hook(const Config * c) {
-    set_file_encoding(lang()->data_encoding(), c);
-    word_lookup.reset(new WordLookup(10, Hash(lang()), Equal(lang())));
-  }
-    
 public:
 
-  WritableDict() : WritableBase(basic_dict, "WritableDict", ".pws", ".per") {
-    have_soundslike = true; fast_lookup = true;
-  }
+  WritableDict() : WritableBase(basic_dict, "WritableDict", ".pws", ".per") {}
 
   Size   size()     const;
   bool   empty()    const;
   
-  using Dictionary::add;
+  PosibErr<void> add(ParmString w) {return Dictionary::add(w);}
   PosibErr<void> add(ParmString w, ParmString s);
 
-  bool lookup (ParmString word, WordEntry &, const SensitiveCompare &) const;
+  bool lookup(ParmString word, const SensitiveCompare *, WordEntry &) const;
 
-  bool stripped_lookup(const char * sondslike, WordEntry &) const;
+  bool clean_lookup(const char * sondslike, WordEntry &) const;
 
   bool soundslike_lookup(const WordEntry & soundslike, WordEntry &) const;
   bool soundslike_lookup(ParmString soundslike, WordEntry &) const;
@@ -339,16 +357,15 @@ bool WritableDict::empty() const
   return word_lookup->empty();
 }
 
-bool WritableDict::lookup(ParmString word, WordEntry & o,
-                        const SensitiveCompare & c) const
+bool WritableDict::lookup(ParmString word, const SensitiveCompare * c,
+                          WordEntry & o) const
 {
   o.clear();
   pair<WordLookup::iterator, WordLookup::iterator> p(word_lookup->equal_range(word));
   while (p.first != p.second) {
-    if (c(word,*p.first)) {
+    if ((*c)(word,*p.first)) {
       o.what = WordEntry::Word;
-      o.word = *p.first;
-      o.aff  = "";
+      set_word(o, *p.first);
       return true;
     }
     ++p.first;
@@ -356,21 +373,20 @@ bool WritableDict::lookup(ParmString word, WordEntry & o,
   return false;
 }
 
-bool WritableDict::stripped_lookup(const char * sl, WordEntry & o) const
+bool WritableDict::clean_lookup(const char * sl, WordEntry & o) const
 {
   o.clear();
   pair<WordLookup::iterator, WordLookup::iterator> p(word_lookup->equal_range(sl));
   if (p.first == p.second) return false;
   o.what = WordEntry::Word;
-  o.word = *p.first;
-  o.aff  = "";
+  set_word(o, *p.first);
   return true;
   // FIXME: Deal with multiple entries
 }  
 
 bool WritableDict::soundslike_lookup(const WordEntry & word, WordEntry & o) const 
 {
-  if (have_soundslike) {
+  if (use_soundslike) {
 
     const StrVector * tmp 
       = (const StrVector *)(word.intr[0]);
@@ -383,6 +399,8 @@ bool WritableDict::soundslike_lookup(const WordEntry & word, WordEntry & o) cons
       
     o.what = WordEntry::Word;
     o.word = word.word;
+    o.word_size = word.word_size;
+    o.word_info = word.word_info;
     o.aff  = "";
     
   }
@@ -391,7 +409,7 @@ bool WritableDict::soundslike_lookup(const WordEntry & word, WordEntry & o) cons
 
 bool WritableDict::soundslike_lookup(ParmString word, WordEntry & o) const 
 {
-  if (have_soundslike) {
+  if (use_soundslike) {
 
     o.clear();
     SoundslikeLookup::const_iterator i = soundslike_lookup_.find(word);
@@ -405,18 +423,18 @@ bool WritableDict::soundslike_lookup(ParmString word, WordEntry & o) const
   
   } else {
 
-    return WritableDict::stripped_lookup(word, o);
+    return WritableDict::clean_lookup(word, o);
 
   }
 }
 
 SoundslikeEnumeration * WritableDict::soundslike_elements() const {
-  if (have_soundslike)
+  if (use_soundslike)
     return new SoundslikeElements(soundslike_lookup_.begin(), 
                                   soundslike_lookup_.end());
   else
-    return new StrippedElements(word_lookup->begin(),
-                                word_lookup->end());
+    return new CleanElements(word_lookup->begin(),
+                             word_lookup->end());
 }
 
 WritableDict::Enum * WritableDict::detailed_elements() const {
@@ -428,17 +446,26 @@ PosibErr<void> WritableDict::add(ParmString w, ParmString s) {
   RET_ON_ERR(check_if_valid(*lang(),w));
   SensitiveCompare c(lang());
   WordEntry we;
-  if (WritableDict::lookup(w,we,c)) return no_err;
-  const char * w2 = buffer.dup(w);
-  word_lookup->insert(w2);
-  if (have_soundslike)
-    soundslike_lookup_[buffer.dup(s)].push_back(w2);
+  if (WritableDict::lookup(w,&c,we)) return no_err;
+  byte * w2;
+  w2 = (byte *)buffer.alloc(w.size() + 3);
+  *w2++ = lang()->get_word_info(w);
+  *w2++ = w.size();
+  memcpy(w2, w.str(), w.size() + 1);
+  word_lookup->insert((char *)w2);
+  if (use_soundslike) {
+    byte * s2;
+    s2 = (byte *)buffer.alloc(s.size() + 2);
+    *s2++ = s.size();
+    memcpy(s2, s.str(), s.size() + 1);
+    soundslike_lookup_[(char *)s2].push_back((char *)w2);
+  }
   return no_err;
 }
 
 PosibErr<void> WritableDict::merge(FStream & in, 
-                                 ParmString file_name, 
-                                 const Config * config)
+                                   ParmString file_name, 
+                                   Config * config)
 {
   typedef PosibErr<void> Ret;
   unsigned int ver;
@@ -459,7 +486,7 @@ PosibErr<void> WritableDict::merge(FStream & in,
 
   split(dp);
   {
-    Ret pe = set_check_lang(dp.key, config);
+    Ret pe = set_check_lang(dp.key, *config);
     if (pe.has_err())
       return pe.with_file(file_name);
   }
@@ -468,9 +495,9 @@ PosibErr<void> WritableDict::merge(FStream & in,
 
   split(dp);
   if (dp.key.size > 0)
-    set_file_encoding(dp.key, config);
+    set_file_encoding(dp.key, *config);
   else
-    set_file_encoding("", config);
+    set_file_encoding("", *config);
   
   ConvP conv(iconv);
   while (getline(in, dp, buf)) {
@@ -492,16 +519,12 @@ PosibErr<void> WritableDict::save(FStream & out, ParmString file_name)
   out.printf("personal_ws-1.1 %s %i %s\n", 
              lang_name(), word_lookup->size(), file_encoding.c_str());
 
-  SoundslikeLookup::const_iterator i = soundslike_lookup_.begin();
-  SoundslikeLookup::const_iterator e = soundslike_lookup_.end();
+  WordLookup::const_iterator i = word_lookup->begin();
+  WordLookup::const_iterator e = word_lookup->end();
     
-  StrVector::const_iterator j;
-  
   ConvP conv(oconv);
   for (;i != e; ++i) {
-    for (j = i->second.begin(); j != i->second.end(); ++j) {
-      out.printf("%s\n", conv(*j));
-    }
+    out.printf("%s\n", conv(*i));
   }
   return no_err;
 }
@@ -513,29 +536,17 @@ PosibErr<void> WritableDict::save(FStream & out, ParmString file_name)
 
 static inline StrVector * get_vector(Str s) 
 {
-  return (StrVector *)(s - sizeof(StrVector));
+  return (StrVector *)(s - sizeof(StrVector) - 2);
 }
 
 class WritableReplDict : public WritableBase
 {
-private:
-  StackPtr<WordLookup> word_lookup;
-  SoundslikeLookup         soundslike_lookup_;
-  StringBuffer             buffer;
-
   WritableReplDict(const WritableReplDict&);
   WritableReplDict& operator=(const WritableReplDict&);
 
-protected:
-  void set_lang_hook(const Config * c) {
-    set_file_encoding(lang()->data_encoding(), c);
-    word_lookup.reset(new WordLookup(10, Hash(lang()), Equal(lang())));
-  }
-
 public:
   WritableReplDict() : WritableBase(replacement_dict, "WritableReplDict", ".prepl",".rpl") 
   {
-    have_soundslike = true;
     fast_lookup = true;
   }
   ~WritableReplDict();
@@ -543,9 +554,9 @@ public:
   Size   size()     const;
   bool   empty()    const;
 
-  bool lookup(ParmString, WordEntry &, const SensitiveCompare &) const;
+  bool lookup(ParmString, const SensitiveCompare *, WordEntry &) const;
 
-  bool stripped_lookup(ParmString sondslike, WordEntry &) const;
+  bool clean_lookup(ParmString sondslike, WordEntry &) const;
 
   bool soundslike_lookup(const WordEntry &, WordEntry &) const;
   bool soundslike_lookup(ParmString, WordEntry &) const;
@@ -556,12 +567,13 @@ public:
   WordEntryEnumeration * detailed_elements() const;
   SoundslikeEnumeration * soundslike_elements() const;
       
-  using Dictionary::add_repl;
+  PosibErr<void> add_repl(ParmString mis, ParmString cor) {
+    return Dictionary::add_repl(mis,cor);}
   PosibErr<void> add_repl(ParmString mis, ParmString cor, ParmString s);
 
 private:
   PosibErr<void> save(FStream &, ParmString );
-  PosibErr<void> merge(FStream &, ParmString , const Config * config);
+  PosibErr<void> merge(FStream &, ParmString , Config * config);
 };
 
 WritableReplDict::Size WritableReplDict::size() const 
@@ -574,15 +586,15 @@ bool WritableReplDict::empty() const
   return word_lookup->empty();
 }
     
-bool WritableReplDict::lookup(ParmString word, WordEntry & o,
-                           const SensitiveCompare & c) const
+bool WritableReplDict::lookup(ParmString word, const SensitiveCompare * c,
+                              WordEntry & o) const
 {
   o.clear();
   pair<WordLookup::iterator, WordLookup::iterator> p(word_lookup->equal_range(word));
   while (p.first != p.second) {
-    if (c(word,*p.first)) {
+    if ((*c)(word,*p.first)) {
       o.what = WordEntry::Misspelled;
-      o.word = *p.first;
+      set_word(o, *p.first);
       o.intr[0] = (void *)*p.first;
       return true;
     }
@@ -591,13 +603,13 @@ bool WritableReplDict::lookup(ParmString word, WordEntry & o,
   return false;
 }
 
-bool WritableReplDict::stripped_lookup(ParmString sl, WordEntry & o) const
+bool WritableReplDict::clean_lookup(ParmString sl, WordEntry & o) const
 {
   o.clear();
   pair<WordLookup::iterator, WordLookup::iterator> p(word_lookup->equal_range(sl));
   if (p.first == p.second) return false;
   o.what = WordEntry::Misspelled;
-  o.word = *p.first;
+  set_word(o, *p.first);
   o.intr[0] = (void *)*p.first;
   return true;
   // FIXME: Deal with multiple entries
@@ -605,7 +617,7 @@ bool WritableReplDict::stripped_lookup(ParmString sl, WordEntry & o) const
 
 bool WritableReplDict::soundslike_lookup(const WordEntry & word, WordEntry & o) const 
 {
-  if (have_soundslike) {
+  if (use_soundslike) {
     const StrVector * tmp = (const StrVector *)(word.intr[0]);
     o.clear();
     o.what = WordEntry::Misspelled;
@@ -619,7 +631,7 @@ bool WritableReplDict::soundslike_lookup(const WordEntry & word, WordEntry & o)
 
 bool WritableReplDict::soundslike_lookup(ParmString soundslike, WordEntry & o) const
 {
-  if (have_soundslike) {
+  if (use_soundslike) {
     o.clear();
     SoundslikeLookup::const_iterator i = soundslike_lookup_.find(soundslike);
     if (i == soundslike_lookup_.end()) {
@@ -630,17 +642,17 @@ bool WritableReplDict::soundslike_lookup(ParmString soundslike, WordEntry & o) c
       return true;
     }
   } else {
-    return WritableReplDict::stripped_lookup(soundslike, o);
+    return WritableReplDict::clean_lookup(soundslike, o);
   }
 }
 
 SoundslikeEnumeration * WritableReplDict::soundslike_elements() const {
-  if (have_soundslike)
+  if (use_soundslike)
     return new SoundslikeElements(soundslike_lookup_.begin(), 
                                   soundslike_lookup_.end());
   else
-    return new StrippedElements(word_lookup->begin(),
-                                word_lookup->end());
+    return new CleanElements(word_lookup->begin(),
+                             word_lookup->end());
 }
 
 WritableReplDict::Enum * WritableReplDict::detailed_elements() const {
@@ -652,7 +664,7 @@ static void repl_next(WordEntry * w)
 {
   const Str * i   = (const Str *)(w->intr[0]);
   const Str * end = (const Str *)(w->intr[1]);
-  w->word = *i;
+  set_word(*w, *i);
   ++i;
   if (i == end) w->adv_ = 0;
 }
@@ -662,8 +674,7 @@ static void repl_init(const StrVector * tmp, WordEntry & o)
   o.what = WordEntry::Word;
   const Str * i   = tmp->pbegin();
   const Str * end = tmp->pend();
-  o.word = *i;
-  o.aff  = "";
+  set_word(o, *i);
   ++i;
   if (i != end) {
     o.intr[0] = (void *)i;
@@ -682,7 +693,7 @@ bool WritableReplDict::repl_lookup(const WordEntry & w, WordEntry & o) const
   } else {
     SensitiveCompare c(lang()); // FIXME: This is not exactly right
     WordEntry tmp;
-    WritableReplDict::lookup(w.word, tmp, c);
+    WritableReplDict::lookup(w.word, &c, tmp);
     repls = get_vector(tmp.word);
     if (!repls) return false;
   }
@@ -700,7 +711,7 @@ bool WritableReplDict::repl_lookup(ParmString word, WordEntry & o) const
 
 PosibErr<void> WritableReplDict::add_repl(ParmString mis, ParmString cor, ParmString sl) 
 {
-  Str m, c, s;
+  Str m;
   SensitiveCompare cmp(lang()); // FIXME: I don't think this is completely correct
   WordEntry we;
 
@@ -710,11 +721,13 @@ PosibErr<void> WritableReplDict::add_repl(ParmString mis, ParmString cor, ParmSt
   for (; p != p0.second && !cmp(mis,*p); ++p);
 
   if (p == p0.second) {
-    char * m0  = (char *)buffer.alloc(sizeof(StrVector) + mis.size() + 1, sizeof(void *));
+    byte * m0  = (byte *)buffer.alloc(sizeof(StrVector) + mis.size() + 3, sizeof(void *));
     new (m0) StrVector;
     m0 += sizeof(StrVector);
+    *m0++ = lang()->get_word_info(mis);
+    *m0++ = mis.size();
     memcpy(m0, mis.str(), mis.size() + 1);
-    m = m0;
+    m = (char *)m0;
     p = word_lookup->insert(m).first;
   } else {
     m = *p;
@@ -725,12 +738,17 @@ PosibErr<void> WritableReplDict::add_repl(ParmString mis, ParmString cor, ParmSt
   for (StrVector::iterator i = v->begin(); i != v->end(); ++i)
     if (cmp(cor, *i)) return no_err;
     
-  c = buffer.dup(cor);
-  get_vector(m)->push_back(c);
+  byte * c0 = (byte *)buffer.alloc(cor.size() + 3);
+  *c0++ = lang()->get_word_info(cor);
+  *c0++ = cor.size();
+  memcpy(c0, cor.str(), cor.size() + 1);
+  v->push_back((char *)c0);
 
-  if (have_soundslike) {
-    s = buffer.dup(sl);
-    soundslike_lookup_[s].push_back(m);
+  if (use_soundslike) {
+    byte * s0 = (byte *)buffer.alloc(sl.size() + 2);
+    *s0++ = sl.size();
+    memcpy(s0, sl.str(), sl.size() + 1);
+    soundslike_lookup_[(char *)s0].push_back(m);
   }
 
   return no_err;
@@ -758,8 +776,8 @@ PosibErr<void> WritableReplDict::save (FStream & out, ParmString file_name)
 }
 
 PosibErr<void> WritableReplDict::merge(FStream & in,
-                                    ParmString file_name, 
-                                    const Config * config)
+                                       ParmString file_name, 
+                                       Config * config)
 {
   typedef PosibErr<void> Ret;
   unsigned int version;
@@ -782,7 +800,7 @@ PosibErr<void> WritableReplDict::merge(FStream & in,
 
   split(dp);
   {
-    Ret pe = set_check_lang(dp.key, config);
+    Ret pe = set_check_lang(dp.key, *config);
     if (pe.has_err())
       return pe.with_file(file_name);
   }
@@ -797,9 +815,9 @@ PosibErr<void> WritableReplDict::merge(FStream & in,
 
   split(dp);
   if (dp.key.size > 0)
-    set_file_encoding(dp.key, config);
+    set_file_encoding(dp.key, *config);
   else
-    set_file_encoding("", config);
+    set_file_encoding("", *config);
 
   if (version == 11) {
 
